import { PrismaClient } from '../db/index.js';
import { Gzip } from '../util/index.js';
class AssistantMonitoring {
    async list({ decodeContent = false } = {}) {
        const data = await PrismaClient.assistantMonitoring.findMany();
        if (decodeContent) {
            return data.map((row) => {
                row.content = row.content ? Gzip.decode(row.content) : row.content;
                return row;
            });
        }
        return data;
    }
    async save(params) {
        if (Number.isNaN(params.interval)) {
            throw new Error('INVALID_INTERVAL_TIME');
        }
        params.interval = Number(params.interval);
        const { interval, name, monitoringId, description, content } = params;
        const data = {
            monitoringId,
            name,
            description,
            content: content ? Gzip.encode(content) || '' : content,
            interval,
        };
        const result = await PrismaClient.assistantMonitoring.create({ data });
        return result;
    }
    async modify(params) {
        const { id } = params;
        if (!id)
            throw new Error('INVALID_ID_TO_UPDATE');
        if (Number.isNaN(params.interval))
            throw new Error('INVALID_INVERVAL_VALUE');
        params.interval = Number(params.interval);
        const { monitoringId, name, interval, description, isActive, content = '', } = params;
        const result = await PrismaClient.assistantMonitoring.update({
            where: { id },
            data: {
                monitoringId,
                name,
                interval,
                description,
                isActive,
                content: content ? Gzip.encode(content) || '' : content,
            },
        });
        return result;
    }
    async delete(params) {
        if (!Array.isArray(params.monitoringIds) || !params.monitoringIds.length) {
            throw new Error('INVALID_MONITORING_IDS_TO_REMOVE');
        }
        await PrismaClient.assistantMonitoring.deleteMany({
            where: {
                monitoringId: {
                    in: params.monitoringIds,
                },
            },
        });
    }
}
const instance = new AssistantMonitoring();
export { instance as AssistantMonitoring };
export default instance;
