-- CreateTable
CREATE TABLE "Server" (
    "id" TEXT NOT NULL PRIMARY KEY,
    "name" TEXT NOT NULL,
    "protocol" TEXT NOT NULL DEFAULT 'http',
    "host" TEXT NOT NULL,
    "port" INTEGER NOT NULL DEFAULT 2375,
    "isActive" TEXT NOT NULL DEFAULT 'S',
    "deployEnabled" TEXT NOT NULL DEFAULT 'N',
    "createdAt" DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    "updatedAt" DATETIME NOT NULL
);

-- CreateTable
CREATE TABLE "Product" (
    "id" TEXT NOT NULL PRIMARY KEY,
    "devopsId" INTEGER NOT NULL,
    "productName" TEXT NOT NULL,
    "description" TEXT,
    "requirements" TEXT,
    "productImage" TEXT,
    "isActive" TEXT NOT NULL DEFAULT 'S',
    "createdAt" DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    "updatedAt" DATETIME NOT NULL
);

-- CreateTable
CREATE TABLE "ProductSetting" (
    "id" TEXT NOT NULL PRIMARY KEY,
    "devopsId" INTEGER NOT NULL,
    "config" TEXT NOT NULL,
    CONSTRAINT "ProductSetting_devopsId_fkey" FOREIGN KEY ("devopsId") REFERENCES "Product" ("devopsId") ON DELETE RESTRICT ON UPDATE CASCADE
);

-- CreateTable
CREATE TABLE "UpdaterVersion" (
    "id" TEXT NOT NULL PRIMARY KEY,
    "version" TEXT NOT NULL,
    "approvedVersion" TEXT NOT NULL DEFAULT 'N',
    "downloads" INTEGER NOT NULL DEFAULT 0,
    "isActive" TEXT NOT NULL DEFAULT 'S',
    "createdAt" DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    "updatedAt" DATETIME NOT NULL
);

-- CreateTable
CREATE TABLE "Customer" (
    "id" TEXT NOT NULL PRIMARY KEY,
    "name" TEXT NOT NULL,
    "assistantUrl" TEXT NOT NULL,
    "createdAt" DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    "updatedAt" DATETIME NOT NULL
);

-- CreateTable
CREATE TABLE "AssistantMonitoring" (
    "id" TEXT NOT NULL PRIMARY KEY,
    "monitoringId" TEXT NOT NULL,
    "description" TEXT NOT NULL,
    "interval" INTEGER NOT NULL,
    "isActive" TEXT NOT NULL DEFAULT 'S',
    "createdAt" DATETIME NOT NULL DEFAULT CURRENT_TIMESTAMP,
    "updatedAt" DATETIME NOT NULL
);

-- CreateTable
CREATE TABLE "_requiredProducts" (
    "A" TEXT NOT NULL,
    "B" TEXT NOT NULL,
    CONSTRAINT "_requiredProducts_A_fkey" FOREIGN KEY ("A") REFERENCES "Product" ("id") ON DELETE CASCADE ON UPDATE CASCADE,
    CONSTRAINT "_requiredProducts_B_fkey" FOREIGN KEY ("B") REFERENCES "Product" ("id") ON DELETE CASCADE ON UPDATE CASCADE
);

-- CreateIndex
CREATE UNIQUE INDEX "Server_name_key" ON "Server"("name");

-- CreateIndex
CREATE UNIQUE INDEX "Product_devopsId_key" ON "Product"("devopsId");

-- CreateIndex
CREATE UNIQUE INDEX "ProductSetting_devopsId_key" ON "ProductSetting"("devopsId");

-- CreateIndex
CREATE UNIQUE INDEX "UpdaterVersion_version_key" ON "UpdaterVersion"("version");

-- CreateIndex
CREATE UNIQUE INDEX "Customer_name_key" ON "Customer"("name");

-- CreateIndex
CREATE UNIQUE INDEX "Customer_assistantUrl_key" ON "Customer"("assistantUrl");

-- CreateIndex
CREATE UNIQUE INDEX "AssistantMonitoring_monitoringId_key" ON "AssistantMonitoring"("monitoringId");

-- CreateIndex
CREATE UNIQUE INDEX "_requiredProducts_AB_unique" ON "_requiredProducts"("A", "B");

-- CreateIndex
CREATE INDEX "_requiredProducts_B_index" ON "_requiredProducts"("B");
